Language

Enum Language 

pub enum Language {
Show 348 variants Abkhaz, Acehnese, Afrikaans, Ahom, AkanFante, AkanTwi, Akkadian, Albanian, AlbanianTosk, Amharic, AncientGreek, AncientNorthArabian, AncientSouthArabian, Angkola, Arabic, ArabicEgyptian, ArabicMesopotamian, ArabicMoroccan, ArabicNajdi, ArabicNorthLevantine, ArabicSouthernYemeni, ArabicSouthLevantine, ArabicSudanese, ArabicTunisian, AramaicElymaic, AramaicHatran, AramaicImperial, AramaicMandaic, AramaicNabataean, AramaicPalmyrene, AramaicSamaritan, AramaicSyriac, Armenian, Assamese, Asturian, Avestan, Awadhi, AymaraCentral, AzerbaijaniNorth, AzerbaijaniSouth, Balinese, Bambara, Bamum, Banjar, Bantawa, Bashkir, Basque, Bassa, Belarusian, Bemba, Bengali, Bhojpuri, Bhumij, BishnupriyaManipuri, Bosnian, Buginese, Buhid, Bulgarian, Burmese, Buryat, Carian, Catalan, CaucasianAlbanian, Cebuano, Chakma, ChamEastern, ChamWestern, Chechen, Cherokee, Chhattisgarhi, ChineseCantonese, ChineseMandarin, ChineseTuhua, Chokwe, Chorasmian, ChurchSlavonic, Chuvash, Coptic, Cree, CreoleHaitian, Croatian, Czech, Danish, Dhivehi, Dholuo, DinkaSouthwestern, Dogri, DogriKangri, Dutch, Dyula, Dzongkha, EgyptianHieroglyphs, English, Esperanto, Estonian, Etruscan, Ewe, Faroese, Fijian, Filipino, Finnish, Fon, French, Friulian, FulaPulaar, FulaPular, FulfuldeNigerian, GaelicScottish, Galician, Ganda, Gandhari, Geez, Georgian, German, Gondi, Gothic, Greek, GuaraniParaguayan, Gujarati, Gurung, Hanunoo, Hausa, Hawaiian, Hebrew, HebrewSamaritan, Hindi, Hittite, Hmong, Ho, Hungarian, Icelandic, Igbo, Ilocano, Indonesian, Inuktitut, Irish, Isan, Italian, Japanese, Javanese, Jingpho, Kabiye, Kabuverdianu, Kabyle, Kamba, Kannada, KanuriCentral, KarenSgaw, Karo, Kashmiri, KayahEastern, KayahWestern, Kazakh, Khitan, Khmer, KhmerNorthern, KikongoKituba, Kikuyu, Kimbundu, Kinyarwanda, KomiPermyak, KomiZyrian, Korean, KurdishCentral, KurdishNorthern, KurdishSouthern, Kurukh, Kutchi, Kyrgyz, Lao, Latgalian, Latin, Latvian, Lepcha, Ligurian, Limbu, Limburgish, Lingala, Lisu, Lithuanian, Lombard, LubaKasai, LuwianCuneiform, LuwianHieroglyphic, Luxembourgish, Lycian, Lydian, Macedonian, Magahi, Maithili, Makassarese, MalagasyPlateau, Malay, Malayalam, Maltese, Mandailing, Manding, Maori, Marathi, MariEastern, Marwari, Math, Medefaidrin, Meitei, Mende, Meroitic, MiddlePersianManichaean, MiddlePersianPahlavi, Minangkabau, Minoan, MinoanLinearA, Mizo, Mon, MongolianBuryat, MongolianKhalkha, Mossi, Mro, Mundari, MycenaeanGreek, Nenets, Nepali, Newar, NigerianPidgin, NorthernThai, NorwegianBokmal, NorwegianNynorsk, Nuer, Nuosu, Nyanja, Occitan, Odia, Oirat, Ojibwe, OldEnglish, OldIrish, OldJavanese, OldNorse, OldPersian, OldTurkic, OldUyghur, OromoSouthern, OromoWestCentral, Osage, Oscan, Ossetian, Pakpak, Pangasinan, Papiamento, Parthian, PashtoSouthern, PersianDari, PersianFarsi, Phoenician, Polish, Portuguese, Prakrit, PunjabiEastern, QuechuaAyacucho, Rejang, Rohingya, Romanian, Rundi, Russian, Sambalpuri, SamiNorthern, Samoan, Sango, Sanskrit, SanskritVedic, Santali, Saraiki, Sardinian, Saurashtra, Sepedi, Serbian, Serer, Sesotho, Shan, Shona, Sicilian, Sidetic, SignLanguages, Silesian, Simalungun, Sindhi, Sinhala, Slovak, Slovenian, Sogdian, Somali, Sora, Spanish, Sumerian, Sundanese, Sunuwar, Swahili, Swati, Swedish, Sylheti, Tagbanwa, TaiDam, TaiDon, TaiLue, TaiNuea, TaiYo, Tajik, Tamasheq, TamazightCentralAtlas, Tamil, Tangsa, Tangut, Tatar, TatarCrimean, Tedim, Telugu, Thai, Tibetan, Tigrinya, TobaBatak, TokPisin, Toto, Tsonga, Tswana, Tulu, Tumbuka, Turkish, Turkmen, Ugaritic, Ukrainian, Umbrian, Umbundu, Unknown, Urdu, Uyghur, UzbekNorthern, Vai, Venetian, Vietnamese, Wancho, Waray, Welsh, Wolof, Xhosa, YiddishEastern, Yoruba, Zaghawa, Zhangzhung, Zulu,
}
Int representation is unstable and can be changed anytime. Code representation (const into_code/from_code) or string representation (const into_str/from_str) are more stable.

Variants



Abkhaz



Acehnese



Afrikaans



Ahom



AkanFante



AkanTwi

default Akan



Akkadian



Albanian

Macro, unique scripts



AlbanianTosk



Amharic



AncientGreek



AncientNorthArabian

Group



AncientSouthArabian

Group



Angkola



Arabic



ArabicEgyptian



ArabicMesopotamian



ArabicMoroccan



ArabicNajdi



ArabicNorthLevantine



ArabicSouthernYemeni



ArabicSouthLevantine



ArabicSudanese



ArabicTunisian



AramaicElymaic



AramaicHatran



AramaicImperial



AramaicMandaic



AramaicNabataean



AramaicPalmyrene



AramaicSamaritan



AramaicSyriac



Armenian



Assamese



Asturian



Avestan



Awadhi



AymaraCentral



AzerbaijaniNorth

Latin



AzerbaijaniSouth

Arabic



Balinese



Bambara



Bamum



Banjar



Bantawa



Bashkir



Basque



Bassa



Belarusian



Bemba



Bengali



Bhojpuri



Bhumij



BishnupriyaManipuri



Bosnian



Buginese



Buhid



Bulgarian



Burmese



Buryat



Carian



Catalan



CaucasianAlbanian



Cebuano



Chakma



ChamEastern



ChamWestern



Chechen



Cherokee



Chhattisgarhi



ChineseCantonese



ChineseMandarin

default Chinese



ChineseTuhua



Chokwe



Chorasmian



ChurchSlavonic



Chuvash



Coptic



Cree

Macro, unique script



CreoleHaitian



Croatian



Czech



Danish



Dhivehi



Dholuo



DinkaSouthwestern



Dogri



DogriKangri



Dutch



Dyula



Dzongkha



EgyptianHieroglyphs



English



Esperanto



Estonian



Etruscan



Ewe



Faroese



Fijian



Filipino



Finnish



Fon



French



Friulian



FulaPulaar



FulaPular



FulfuldeNigerian



GaelicScottish



Galician



Ganda



Gandhari



Geez



Georgian



German



Gondi

Macro, unique scripts



Gothic



Greek



GuaraniParaguayan



Gujarati



Gurung



Hanunoo



Hausa



Hawaiian



Hebrew



HebrewSamaritan



Hindi



Hittite



Hmong

Macro, unique scripts



Ho



Hungarian



Icelandic



Igbo



Ilocano



Indonesian



Inuktitut

Macro, unique script



Irish



Isan



Italian



Japanese



Javanese



Jingpho



Kabiye



Kabuverdianu



Kabyle



Kamba



Kannada



KanuriCentral



KarenSgaw



Karo



Kashmiri



KayahEastern



KayahWestern



Kazakh



Khitan



Khmer



KhmerNorthern



KikongoKituba



Kikuyu



Kimbundu



Kinyarwanda



KomiPermyak



KomiZyrian



Korean



KurdishCentral



KurdishNorthern



KurdishSouthern



Kurukh



Kutchi



Kyrgyz



Lao



Latgalian



Latin



Latvian



Lepcha



Ligurian



Limbu



Limburgish



Lingala



Lisu



Lithuanian



Lombard



LubaKasai



LuwianCuneiform



LuwianHieroglyphic



Luxembourgish



Lycian



Lydian



Macedonian



Magahi



Maithili



Makassarese



MalagasyPlateau



Malay



Malayalam



Maltese



Mandailing



Manding

Macro, unique script



Maori



Marathi



MariEastern



Marwari

Macro, unique script



Math



Medefaidrin



Meitei



Mende



Meroitic



MiddlePersianManichaean



MiddlePersianPahlavi



Minangkabau



Minoan



MinoanLinearA



Mizo



Mon



MongolianBuryat



MongolianKhalkha



Mossi



Mro



Mundari



MycenaeanGreek



Nenets



Nepali



Newar



NigerianPidgin



NorthernThai



NorwegianBokmal



NorwegianNynorsk



Nuer



Nuosu



Nyanja



Occitan



Odia



Oirat



Ojibwe

Macro, unique script



OldEnglish



OldIrish



OldJavanese



OldNorse



OldPersian



OldTurkic



OldUyghur



OromoSouthern



OromoWestCentral



Osage



Oscan



Ossetian



Pakpak



Pangasinan



Papiamento



Parthian



PashtoSouthern



PersianDari

Afghani



PersianFarsi

Iranian



Phoenician



Polish



Portuguese



Prakrit

Group



PunjabiEastern



QuechuaAyacucho



Rejang



Rohingya



Romanian



Rundi



Russian



Sambalpuri



SamiNorthern



Samoan



Sango



Sanskrit



SanskritVedic



Santali



Saraiki



Sardinian

Macro, hard to separate



Saurashtra



Sepedi



Serbian



Serer



Sesotho



Shan



Shona



Sicilian



Sidetic



SignLanguages

Group



Silesian



Simalungun



Sindhi



Sinhala



Slovak



Slovenian



Sogdian



Somali



Sora



Spanish



Sumerian



Sundanese



Sunuwar



Swahili



Swati



Swedish



Sylheti



Tagbanwa



TaiDam



TaiDon



TaiLue



TaiNuea



TaiYo



Tajik



Tamasheq



TamazightCentralAtlas



Tamil



Tangsa

Macro, unique script



Tangut



Tatar



TatarCrimean



Tedim



Telugu



Thai



Tibetan



Tigrinya



TobaBatak



TokPisin



Toto



Tsonga



Tswana



Tulu



Tumbuka



Turkish



Turkmen



Ugaritic



Ukrainian



Umbrian



Umbundu



Unknown

Undetermined language based on alphabets



Urdu



Uyghur



UzbekNorthern



Vai



Venetian



Vietnamese



Wancho



Waray



Welsh



Wolof



Xhosa



YiddishEastern



Yoruba



Zaghawa



Zhangzhung



Zulu

Implementations

Source

impl Language

pub const fn into_code(self) -> u32

20-bit code (compacted ISO 639-3 code)

pub const fn into_str(self) -> &'static str

ISO 639-3 code string

pub const fn into_2letter(self) -> Option<&'static str>

ISO 639-1 code string

pub const fn from_code(v: u32) -> Option<Self>

20-bit code (compacted ISO 639-3 code)

pub const fn from_bytes(v: &[u8]) -> Option<Self>

ISO 639-3 code string

pub const fn from_str(s: &str) -> Option<Self>

ISO 639-3 code string